{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2023 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{#
  Renders the request details page when including a published record in a community.
#}

{% extends "invenio_requests/community-submission/index.html" %}
